@@ -85,7 +85,7 @@ namespace eval ::teapotclient {
 	set cpuTeapotToLocal(powerpc) [list ppc]
 
 	proc download_extensions {rootdir servers extensions os cpu {existingExts ""}} {
-		foreach chkdefext [list Tcl Tk] {
+		foreach chkdefext [list Tcl Tk msgcat] {
 			if {[lsearch -exact $existingExts $chkdefext] == -1} {
 				lappend existingExts $chkdefext
 			}
