@@ -6,15 +6,20 @@ if [ ! -x "../platform" ]; then
 	exit 1
 fi
 
+if [ "${PLATFORM}" = "tcl" ]; then
+	rm -rf out
+
+	exit 0
+fi
+
 VERS=1.6
 SRC="src/tls${VERS}-src.tar.gz"
 SRCURL="http://sourceforge.net/projects/tls/files/tls/${VERS}/tls${VERS}-src.tar.gz/download"
 BUILDDIR="tls${VERS}"
 WORKDIR="${TMPDIR:-/tmp}/tls-$$${RANDOM}${RANDOM}${RANDOM}"
-PLATFORM="$(../platform)"
 PLATDIR="$(pwd)/out/${PLATFORM}"
 
-export VERS SRC SRCURL BUILDDIR WORKDIR PLATFORM PLATDIR
+export VERS SRC SRCURL BUILDDIR WORKDIR PLATDIR
 
 if [ ! -f "${SRC}" ]; then
 	mkdir src >/dev/null 2>/dev/null
@@ -39,7 +44,7 @@ fi
 		SSLDIR="/usr"
 	fi
 
-	./configure --enable-shared --with-tcl="${TCLCONFIGDIR}" --with-ssl-dir="${SSLDIR}"
+	bash ./configure --enable-shared --with-tcl="${TCLCONFIGDIR}" --with-ssl-dir="${SSLDIR}" ${CONFIGUREEXTRA}
 	${MAKE:-make} || exit 1
 ) || exit 1
 
